@@ -1,11 +1,14 @@
 package compiler
 
 import (
+	"context"
 	"strings"
 	"testing"
+	"time"
 
 	"github.com/projectdiscovery/gologger"
 	"github.com/projectdiscovery/gologger/levels"
+	"github.com/projectdiscovery/nuclei/v3/pkg/types"
 )
 
 func TestNewCompilerConsoleDebug(t *testing.T) {
@@ -18,7 +21,14 @@ func TestNewCompilerConsoleDebug(t *testing.T) {
 	})
 
 	compiler := New()
-	_, err := compiler.Execute("console.log('hello world');", NewExecuteArgs())
+	p, err := WrapScriptNCompile("console.log('hello world');", false)
+	if err != nil {
+		t.Fatal(err)
+	}
+
+	_, err = compiler.ExecuteWithOptions(p, NewExecuteArgs(), &ExecuteOptions{Context: context.Background(),
+		TimeoutVariants: &types.Timeouts{JsCompilerExecutionTimeout: time.Duration(20) * time.Second}},
+	)
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -27,17 +37,6 @@ func TestNewCompilerConsoleDebug(t *testing.T) {
 	}
 }
 
-func TestExecuteResultGetSuccess(t *testing.T) {
-	compiler := New()
-	result, err := compiler.Execute("1+1 == 2", NewExecuteArgs())
-	if err != nil {
-		t.Fatal(err)
-	}
-	if result.GetSuccess() != true {
-		t.Fatalf("expected true, got=%v", result.GetSuccess())
-	}
-}
-
 type noopWriter struct {
 	Callback func(data []byte, level levels.Level)
 }
